@@ -11,16 +11,12 @@ logger.addHandler(stream)
 
 class ModelScoreCallback(tf.keras.callbacks.Callback):
 
-    def __init__(self, score_func: Callable, X, y):
+    def __init__(self, score_func: Callable):
         super().__init__()
         self._score_func = score_func
-        self._X = X
-        self._y = y
 
     def on_epoch_end(self, epoch: int, logs: Optional[Dict[str, Any]] = None):
-        if self._X is None or self._y is None:
-            return 
-        score_df = self._score_func(self._X, self._y)
+        score_df = self._score_func()
         row = score_df[score_df["class"] == "avg"]
         logger.info(row)
         for col in score_df.columns:
