@@ -26,8 +26,7 @@ class BertClassifier(DeepClassifier):
         max_sequence_length: int = 120,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
-        fc_activation: str = "relu",
-        fc_last_activation: str = "tanh",
+        fc_activation: str = "tanh",
         fc_momentum: float = 0.9,
         fc_epsilon: float = 1e-5,
         output_dropout: float = 0.5,
@@ -47,7 +46,6 @@ class BertClassifier(DeepClassifier):
         self.num_fc_layers = num_fc_layers
         self.fc_hidden_size = fc_hidden_size
         self.fc_activation = fc_activation
-        self.fc_last_activation = fc_last_activation
         self.fc_momentum = fc_momentum
         self.fc_epsilon = fc_epsilon
         self.output_dropout = output_dropout
@@ -83,8 +81,7 @@ class BertClassifier(DeepClassifier):
             hidden_size=self.fc_hidden_size,
             output_size=self.num_classes,
             activation=self.fc_activation,
-            last_activation=self.fc_last_activation,
-            batch_normal=self.use_batch_normal,
+            batch_normalization=self.use_batch_normalization,
             momentum=self.fc_momentum,
             epsilon=self.fc_epsilon,
             name="mlp",
